myimagelib
=====

**myimagelib** is a collection of image processing and data analysis tools I developed to facilitate my PhD and postdoc research. Tools include particle tracking, PIV, file batch reading, spatiotemporal correlation analysis, etc.
